# 3yzh

A three-circle calculator, It contains Circle Circles and Cylinders.
It is in Chinese.If you konw how to speak and write or mean these,you can use
Now,you can Download and input python -m main and then it will running

Please comply with local laws and regulations, 
User only has the right to use 
The final interpretation belongs to the author 
For mainland China only. 
You can see or read the log in log.py
This means that you have read and agreed to all the above regulations. 
Welcome Download and use!